/*
 * Copyright (C) 2012 Michael Olbrich <m.olbrich@pengutonix.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */

import QtQuick 1.0
import org.moly.Core 1.0

Item {
	width: 1920
	height: 1080
	property string key: width + "x" + height
	property int load: 0

	Image {
		id: bg
		anchors.fill: parent
		source: "images/" + key + ".jpg"
	}
	Image {
		id: phytec
		anchors.left: parent.left
		anchors.bottom: parent.bottom
		anchors.margins: parent.height/30
		source: "images/logo_phytec_for_" + key + ".png"
	}
	Image {
		id: ptx
		anchors.left: phytec.right
		anchors.bottom: parent.bottom
		anchors.margins: parent.height/30
		anchors.leftMargin: parent.height/10
		source: "images/logo_pengutronix_for_" + key + ".png"
	}
	Text {
		id: mx
		anchors.horizontalCenter: parent.horizontalCenter
		anchors.bottom: parent.bottom
		anchors.margins: parent.height/5
		text: "i.MX6 Quadcore ARM"
		font.pixelSize: parent.height/10
		font.bold: true
	}
	Grid {
		id: grid
		anchors.top: parent.top
		anchors.left: parent.left
		anchors.margins: parent.height/30
		columns: 2
		Repeater {
			model: 4
			Dial {
				value:  cpu.all/1.2
				spring: 1.0
				CpuUsage {
					id: cpu
					interval: 500
					core: index
				}
			}
		}
	}
	Column {
		anchors.verticalCenter: grid.verticalCenter
		anchors.left: grid.right
		anchors.margins: width/3
		spacing: grid.height/20
		Repeater {
			model: 4
			Rectangle {
				height: grid.height/6
				width: height * 2
				radius: height/3
				property bool on: load > index
				color: on ? "skyblue" : "lightgrey"
				Load {
					enabled: on
					level: 100
				}
				Text {
					anchors.centerIn: parent
					text: "Load " + (index + 1)
					font.pixelSize:parent.height / 2
				}
			}
		}
	}
	MouseArea {
		anchors.fill: parent
		acceptedButtons: Qt.LeftButton | Qt.RightButton
		onClicked: {
			if (mouse.button == Qt.LeftButton) {
				if (load < 4)
					parent.load++
			}
			else {
				if (load > 0)
					parent.load--
			}
			timer.restart()
		}
	}
	Timer {
		id: timer
		interval: 10000
		onTriggered: parent.load = 0
	}
	Component.onCompleted: modaemon.detach()
}
